@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.27 2002/10/09 21:37:05 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.29 2003/06/11 11:44:00 abe Exp $";
 #endif
 
 
@@ -123,6 +123,32 @@ lkup_dev_tty_again:
 #endif	/* defined(HASFDESCFS) && HASFDESCFS==1 */
 
 
+#if	defined(HASKQUEUE)
+/*
+ * process_kqueue() -- process kqueue file
+ *
+ * Strictly speaking this function should appear in dfile.c, because it is
+ * a file processing function.  However, the Net and Open BSD sources don't
+ * require a dfile.c, so this is the next best location for the function.
+ */
+
+void
+process_kqueue(ka)
+	KA_T ka;			/* kqueue file structure address */
+{
+	struct kqueue kq;		/* kqueue structure */
+
+	(void) snpf(Lf->type, sizeof(Lf->type), "KQUEUE");
+	enter_dev_ch(print_kptr(ka, (char *)NULL, 0));
+	if (!ka || kread(ka, (char *)&kq, sizeof(kq)))
+	    return;
+	(void) snpf(Namech, Namechl, "count=%d, state=%#x", kq.kq_count,
+	    kq.kq_state);
+	enter_nm(Namech);
+}
+#endif	/* defined(HASKQUEUE) */
+
+
 /*
  * process_node() - process vnode
  */
@@ -315,8 +341,8 @@ process_overlaid_node:
 		case MOUNT_PROCFS:
 		    Ntype = N_PROC;
 		    break;
-		}
 # endif	/* defined(HASPROCFS) */
+		}
 #else	/* !defined(MOUNT_NONE) */
 		if (strcasecmp(vfs->typnm, "nfs") == 0)
 		    Ntype = N_NFS;
