@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dsock.c,v 1.22 2002/12/20 18:22:24 abe Exp $";
+static char *rcsid = "$Id: dsock.c,v 1.23 2003/03/21 17:41:34 abe Exp $";
 #endif
 
 
@@ -378,7 +378,7 @@ process_socket(sa)
 		unl = sizeof(ua->sun_path) - 1;
 # endif	/* FREEBSDV>460 */ 
 		if ((unl < 0) || (unl >= sizeof(ua->sun_path)))
-		    unl = 0;
+		    unl = sizeof(ua->sun_path) - 1;
 		ua->sun_path[unl] = '\0';
 #endif	/* FREEBSDV<450 */
 
