@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dsock.c,v 1.21 2002/01/16 15:05:10 abe Exp $";
+static char *rcsid = "$Id: dsock.c,v 1.23 2003/06/13 09:51:53 abe Exp $";
 #endif
 
 
@@ -87,7 +87,7 @@ struct tcp_udp {			/* IPv4 TCP and UDP socket
 	unsigned long inode;
 	unsigned long faddr, laddr;	/* foreign & local IPv6 addresses */
 	int fport, lport;		/* foreign & local ports */
-	unsigned long txq, rxq;		/* trasmit & receve queue values */
+	unsigned long txq, rxq;		/* transmit & receive queue values */
 	int proto;			/* 0 = TCP, 1 = UDP */
 	int state;			/* protocol state */
 	struct tcp_udp *next;
@@ -99,7 +99,7 @@ struct tcp_udp6 {			/* IPv6 TCP and UDP socket
 	unsigned long inode;
 	struct in6_addr faddr, laddr;	/* foreign and local IPv6 addresses */
 	int fport, lport;		/* foreign & local ports */
-	unsigned long txq, rxq;		/* trasmit & receve queue values */
+	unsigned long txq, rxq;		/* transmit & receive queue values */
 	int proto;			/* 0 = TCP, 1 = UDP */
 	int state;			/* protocol state */
 	struct tcp_udp6 *next;
@@ -432,7 +432,8 @@ get_ax25(p)
 		    Exit(1);
 		}
 		(void) snpf(da, len + 1, "%s", fp[0]);
-	    }
+	    } else
+		da = (char *)NULL;
 	/*
 	 * Allocate space for the source address.
 	 */
@@ -446,7 +447,8 @@ get_ax25(p)
 		    Exit(1);
 		}
 		(void) snpf(sa, len + 1, "%s", fp[1]);
-	    }
+	    } else
+		sa = (char *)NULL;
 	/*
 	 * Allocate space for the device characters.
 	 */
@@ -460,7 +462,8 @@ get_ax25(p)
 		    Exit(1);
 		}
 		(void) snpf(dev_ch, len + 1, "%s", fp[2]);
-	    }
+	    } else
+		dev_ch = (char *)NULL;
 	/*
 	 * Allocate space for an ax25sin entry, fill it, and link it to its
 	 * hash bucket.
