@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.26 2002/10/08 20:22:10 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.29 2003/06/11 11:45:13 abe Exp $";
 #endif
 
 
@@ -125,6 +125,39 @@ lkup_dev_tty_again:
 #endif	/* defined(HASFDESCFS) && HASFDESCFS==1 */
 
 
+#if	defined(HASKQUEUE)
+/*
+ * process_kqueue() -- process kqueue file
+ *
+ * Strictly speaking this function should appear in dfile.c, because it is
+ * a file processing function.  However, the Net and Open BSD sources don't
+ * require a dfile.c, so this is the next best location for the function.
+ */
+
+void
+process_kqueue(ka)
+	KA_T ka;			/* kqueue file structure address */
+{
+
+# if	defined(OPENBSDV)
+	struct kqueue kq;		/* kqueue structure */
+# endif	/* defined(OPENBSDV) */
+
+	(void) snpf(Lf->type, sizeof(Lf->type), "KQUEUE");
+	enter_dev_ch(print_kptr(ka, (char *)NULL, 0));
+
+# if	defined(OPENBSDV)
+	if (!ka || kread(ka, (char *)&kq, sizeof(kq)))
+	    return;
+	(void) snpf(Namech, Namechl, "count=%d, state=%#x", kq.kq_count,
+	    kq.kq_state);
+	enter_nm(Namech);
+# endif	/* defined(OPENBSDV) */
+
+}
+#endif	/* defined(HASKQUEUE) */
+
+
 /*
  * process_node() - process vnode
  */
@@ -167,6 +200,22 @@ process_node(va)
 
 #endif	/* defined(HASFDESCFS) */
 
+#if	defined(HASEXT2FS)
+# if	defined(HASI_E2FS_PTR)
+	struct ext2fs_dinode ed;
+# endif	/* defined(HASI_E2FS_PTR) */
+	struct ext2fs_dinode *edp = (struct ext2fs_dinode *)NULL;
+#endif	/* defined(HASEXT2FS) */
+
+#if	defined(HASI_FFS1)
+	unsigned char ffs = 0;
+	unsigned char u1s = 0;
+	unsigned char u2s = 0;
+	struct ufs1_dinode u1;
+	struct ufs2_dinode u2;
+	struct ufsmount um;
+#endif	/* defined(HASI_FFS1) */
+
 #if	defined(HASKERNFS)
 	struct kernfs_node kn;
 	struct stat ksb;
@@ -229,6 +278,14 @@ process_overlaid_node:
 	ksbs = 0;
 #endif	/* defined(HASKERNFS) */
 
+#if	defined(HASEXT2FS)
+	edp = (struct ext2fs_dinode *)NULL;
+#endif	/* defined(HASEXT2FS) */
+
+#if	defined(HASI_FFS1)
+	ffs = u1s = u2s = 0;
+#endif	/* defined(HASI_FFS1) */
+
 /*
  * Read the vnode.
  */
@@ -470,12 +527,51 @@ process_overlaid_node:
 	    }
 
 #if	defined(HASEXT2FS)
-	    if (v->v_tag == VT_EXT2FS)
+	    if (v->v_tag == VT_EXT2FS) {
 		nty = EXT2NODE;
-	    else
+
+# if	defined(HASI_E2FS_PTR)
+		if (i.i_din.e2fs_din
+		&&  !kread((KA_T)i.i_din.e2fs_din, (char *)&ed, sizeof(ed)))
+		    edp = &ed;
+# else	/* !defined(HASI_E2FS_PTR) */
+		edp = &i.i_din.e2fs_din;
+# endif	/* defined(HASI_E2FS_PTR) */
+
+	    } else
 #endif	/* defined(HASEXT2FS) */
 
+	    {
 		nty = INODE;
+
+#if	defined(HASI_FFS1)
+		/*
+		 * If there are multiple FFS's, read the relevant structures.
+		 */
+		    if (i.i_ump
+		    &&  !kread((KA_T)i.i_ump, (char *)&um, sizeof(um))) {
+			if (um.um_fstype == UFS1) {
+			    ffs = 1;
+			    if (i.i_din.ffs1_din
+			    &&  !kread((KA_T)i.i_din.ffs1_din, (char *)&u1,
+				       sizeof(u1)))
+			    {
+				u1s = 1;
+			    }
+			} else if (um.um_fstype == UFS2) {
+			    ffs = 2;
+			    if (i.i_din.ffs2_din
+			    &&  !kread((KA_T)i.i_din.ffs2_din, (char *)&u2,
+				       sizeof(u2)))
+			    {
+				u2s = 1;
+			    }
+			}
+		    }
+#endif	/* defined(HASI_FFS1) */
+
+	    }
+
 	    if ((lff = i.i_lockf)) {
 
 	    /*
@@ -494,6 +590,18 @@ process_overlaid_node:
 		    case F_POSIX:
 			if ((KA_T)lf.lf_id == Kpa)
 			    lt = 1;
+
+#if	defined(HAS_LWP_H) && !defined(HAS_LF_LWP)
+			else {
+
+			    struct lwp lw;
+
+			    if (!kread((KA_T)lf.lf_id, (char *)&lw, sizeof(lw))
+			    &&  (KA_T)lw.l_proc == Kpa)
+				lt = 1;
+			}
+#endif	/* defined(HAS_LWP_H) && !defined(HAS_LF_LWP) */
+
 			break;
 		    }
 		    if (!lt)
@@ -564,18 +672,21 @@ process_overlaid_node:
 #if	defined(HASEXT2FS)
 	case EXT2NODE:
 
-# if	defined(HASI_FFS)
-	    dev = i.i_dev;
-	    devs = 1;
-# else	/* !defined(HASI_FFS) */
 	    dev = i.i_dev;
 	    devs = 1;
 	    if ((type == VCHR) || (type == VBLK)) {
-		rdev = i.i_rdev;
-		rdevs = 1;
-	    }
-# endif	/* defined(HASI_FFS) */
 
+# if	defined(HASI_E2FS_PTR)
+		if (edp) {
+		    rdev = edp->e2di_rdev;
+		    rdevs = 1;
+		}
+# else	/* !defined(HASI_E2FS_PTR) */
+		rdev = i.i_din.e2fs_din.e2di_rdev;
+		rdevs = 1;
+# endif	/* defined(HASI_E2FS_PTR) */
+
+	    }
 	    break;
 #endif	/* defined(HASEXT2FS) */
 
@@ -586,11 +697,26 @@ process_overlaid_node:
 
 #if	defined(HASI_FFS)
 		rdev = i.i_ffs_rdev;
+		rdevs = 1;
 #else	/* !defined(HASI_FFS) */
+# if	defined(HASI_FFS1)
+		if (ffs == 1) {
+		    if (u1s) {
+			rdev = u1.di_rdev;
+			rdevs = 1;
+		    }
+		} else if (ffs == 2) {
+		    if (u2s) {
+			rdev = u2.di_rdev;
+			rdevs = 1;
+		    }
+		}
+# else	/* !defined(HASI_FFS1) */
 		rdev = i.i_rdev;
+		rdevs = 1;
+# endif	/* defined(HASI_FFS1) */
 #endif	/* defined(HASI_FFS) */
 
-		rdevs = 1;
 	    }
 	    break;
 
@@ -762,11 +888,26 @@ process_overlaid_node:
 
 #if	defined(HASI_FFS)
 			Lf->sz = (SZOFFTYPE)i.i_ffs_size;
+			Lf->sz_def = 1;
 #else	/* !defined(HASI_FFS) */
+# if	defined(HASI_FFS1)
+			if (ffs == 1) {
+			    if (u1s) {
+				Lf->sz = (SZOFFTYPE)u1.di_size;
+				Lf->sz_def = 1;
+			    }
+			} else if (ffs == 2) {
+			    if (u2s) {
+				Lf->sz = (SZOFFTYPE)u2.di_size;
+				Lf->sz_def = 1;
+			    }
+			}
+# else	/* !defined(HASI_FFS1) */
 			Lf->sz = (SZOFFTYPE)i.i_size;
+			Lf->sz_def = 1;
+# endif	/* defined(HASI_FFS1) */
 #endif	/* defined(HASI_FFS) */
 
-			Lf->sz_def = 1;
 		    }
 
 #if	defined(HASMSDOSFS)
@@ -783,14 +924,15 @@ process_overlaid_node:
 
 #if	defined(HASEXT2FS)
 		    else if (nty == EXT2NODE) {
-
-# if	defined(HASI_E2FS)
+# if	defined(HASI_E2FS_PTR)
+			if (edp) {
+			    Lf->sz = (SZOFFTYPE)edp->e2di_size;
+			    Lf->sz_def = 1;
+			}
+# else	/* !defined(HASI_E2FS_PTR) */
 			Lf->sz = (SZOFFTYPE)i.i_e2fs_size;
-# else	/* !defined(HASI_E2FS) */
-			Lf->sz = (SZOFFTYPE)i.i_size;
-# endif	/* defined(HASI_E2FS) */
-
 			Lf->sz_def = 1;
+# endif	/* defined(HASI_E2FS_PTR) */
 		    }
 #endif	/* defined(HASEXT2FS) */
 
@@ -835,8 +977,24 @@ process_overlaid_node:
 
 # if	defined(HASI_FFS)
 		    Lf->nlink = (long)i.i_ffs_nlink;
+		    Lf->nlink_def = 1;
 # else	/* !defined(HASI_FFS) */
+#  if	defined(HASI_FFS1)
+		    if (ffs == 1) {
+			if (u1s) {
+			    Lf->nlink = (long)u1.di_nlink;
+			    Lf->nlink_def = 1;
+			}
+		    } else if (ffs == 2) {
+			if (u2s) {
+			    Lf->nlink = (long)u2.di_nlink;
+			    Lf->nlink_def = 1;
+			}
+		    }
+#  else	/* !defined(HASI_FFS1) */
 		    Lf->nlink = (long)i.i_nlink;
+		    Lf->nlink_def = 1;
+#  endif	/* defined(HASI_FFS1) */
 # endif	/* defined(HASI_FFS) */
 
 		    Lf->nlink_def = 1;
@@ -852,8 +1010,15 @@ process_overlaid_node:
 
 #if	defined(HASEXT2FS)
 		else if (nty == EXT2NODE) {
-		    Lf->nlink - (long)i.i_e2fs_nlink;
+# if	defined(HASI_E2FS_PTR)
+		    if (edp) {
+			Lf->nlink = (long)edp->e2di_nlink;
+			Lf->nlink_def = 1;
+		    }
+# else	/* !defined(HASI_E2FS_PTR) */
+		    Lf->nlink = (long)i.i_e2fs_nlink;
 		    Lf->nlink_def = 1;
+# endif	/* defined(HASI_E2FS_PTR) */
 		}
 #endif	/* defined(HASEXT2FS) */
 
