@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.44 2002/06/17 01:42:31 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.45 2003/06/11 11:43:07 abe Exp $";
 #endif
 
 
@@ -56,6 +56,13 @@ _PROTOTYPE(static struct l_dev *finddev,(dev_t *dev, dev_t *rdev, int flags));
 					/* look all places */
 
 
+/*
+ * SAM-FS definitions
+ */
+
+#define	SAMFS_NMA_MSG	"(limited SAM-FS info)"
+
+
 _PROTOTYPE(static char isvlocked,(struct vnode *va));
 _PROTOTYPE(static int readinode,(KA_T ia, struct inode *i));
 _PROTOTYPE(static void read_mi,(KA_T s, dev_t *dev, caddr_t so, int *so_st, KA_T *so_ad, struct l_dev **sdp));
@@ -102,29 +109,30 @@ _PROTOTYPE(static void savesockmod,(struct so_so *so, struct so_so *sop, int *so
  */
 
 static KA_T Auvops;		/* auto_vnodeops address */
-static KA_T Avops;		/* [_]afs_vnodeops address */
+static KA_T Avops;		/* afs_vnodeops address */
 static KA_T Cvops;		/* cache_vnodeops address */
 static KA_T Dvops;		/* door_vnodeops address */
 static KA_T Fdops;		/* fdvnodeops address */
-static KA_T Fvops;		/* [_]fifo_vnodeops address */
-static KA_T Hvops;		/* [_]hsfs_vnodeops address */
+static KA_T Fvops;		/* fifo_vnodeops address */
+static KA_T Hvops;		/* hsfs_vnodeops address */
 static KA_T Lvops;		/* lo_vnodeops address */
 static KA_T Mntops;		/* mntvnodeops address */
-static KA_T Mvops;		/* [_]mvfs_vnodeops address */
-static KA_T N3vops;		/* [_]nfs3_vnodeops address */
+static KA_T Mvops;		/* mvfs_vnodeops address */
+static KA_T N3vops;		/* nfs3_vnodeops address */
 static KA_T Nmvops;		/* nm_vnodeops address */
-static KA_T Nvops;		/* [_]nfs_vnodeops address */
-static KA_T Pdvops;		/* [_]pcfs_dvnodeops address */
-static KA_T Pfvops;		/* [_]pcfs_fvnodeops address */
+static KA_T Nvops;		/* nfs_vnodeops address */
+static KA_T Pdvops;		/* pcfs_dvnodeops address */
+static KA_T Pfvops;		/* pcfs_fvnodeops address */
 static KA_T Prvops;		/* prvnodeops address */
-static KA_T Sckvops;		/* [_]sock_vnodeops address */
-static KA_T Spvops;		/* [_]spec_vnodeops address */
-static KA_T Tvops;		/* [_]tmp_vnodeops address */
-static KA_T Uvops;		/* [_]ufs_vnodeops address */
+static KA_T Samvops;		/* samfs_vnodeops address */
+static KA_T Sckvops;		/* sock_vnodeops address */
+static KA_T Spvops;		/* spec_vnodeops address */
+static KA_T Tvops;		/* tmp_vnodeops address */
+static KA_T Uvops;		/* ufs_vnodeops address */
 static KA_T Vvops[VXVOP_NUM];	/* addresses of:
-				 *   [_]fdd_chain_vnops (VXVOP_FDDCH),
-				 *   [_]fdd_vnops (VXVOP_FDD), and
-				 *   [_]vx_vnodeops (VXVOP_REG) */
+				 *   fdd_chain_vnops (VXVOP_FDDCH),
+				 *   fdd_vnops (VXVOP_FDD), and
+				 *   vx_vnodeops (VXVOP_REG) */
 
 
 /*
@@ -167,7 +175,7 @@ ent_fa(a1, a2, d, len)
 		print_kptr(*a2, (char *)NULL, 0));
 #endif	/* solaris<20600 */
 
-	*len = (int) strlen(buf);
+	*len = (int)strlen(buf);
 	return(buf);
 }
 
@@ -214,7 +222,9 @@ is_socket(v)
 	    pf = "/devices/pseudo/";
 #endif	/* solaris<80000 */
 
-	    for (i = n = 0, pfl = strlen(pf); (i < Ndev) && (n < NTCPUDP); i++)
+	    for (i = n = 0, pfl = (int)strlen(pf);
+		 (i < Ndev) && (n < NTCPUDP);
+		 i++)
 	    {
 		if (strncmp(Devtp[i].name, pf, pfl)
 		||  !(ep = strrchr((cp = &Devtp[i].name[pfl]), ':'))
@@ -619,6 +629,8 @@ process_node(va)
 		Pfvops = (KA_T)0;
 	    if (get_Nl_value("prvops", Drive_Nl, &Prvops) < 0)
 		Prvops = (KA_T)0;
+	    if (get_Nl_value("samvops", Drive_Nl, &Samvops) < 0)
+		Samvops = (KA_T)0;
 	    if (get_Nl_value("sckvops", Drive_Nl, &Sckvops) < 0)
 		Sckvops = (KA_T)0;
 	    if (get_Nl_value("spvops", Drive_Nl, &Spvops) < 0)
@@ -953,7 +965,7 @@ vfs_read_error:
 		enter_dev_ch(print_kptr((KA_T)v->v_data, (char *)NULL, 0));
 		if (f.fn_flag & ISPIPE) {
 		    (void) snpf(tbuf, sizeof(tbuf), "PIPE");
-		    tbufx = (int) strlen(tbuf);
+		    tbufx = (int)strlen(tbuf);
 		} else
 		    tbufx = 0;
 
@@ -961,13 +973,13 @@ vfs_read_error:
 		if (f.fn_mate) {
 		    (void) snpf(&tbuf[tbufx], sizeof(tbuf) - tbufx, "->%s",
 			print_kptr((KA_T)f.fn_mate, (char *)NULL, 0));
-		    tbufx = (int) strlen(tbuf);
+		    tbufx = (int)strlen(tbuf);
 		}
 #else	/* solaris>=20500 */
 		if (f.fn_dest) {
 		    (void) snpf(&tbuf[tbufx], sizeof(tbuf) - tbufx, "->%s",
 			print_kptr((KA_T)f.fn_dest, (char *)NULL, 0));
-		    tbufx = (int) strlen(tbuf);
+		    tbufx = (int)strlen(tbuf);
 		}
 #endif	/* solaris<20500 */
 
@@ -1011,6 +1023,9 @@ vfs_read_error:
 	    if (read_ntn(va, (KA_T)v->v_data, &t))
 		return;
 	    break;
+	case N_SAMFS:
+	    (void) add_nma(SAMFS_NMA_MSG, (int)strlen(SAMFS_NMA_MSG));
+	    break;
 	case N_STREAM:
 	    if (read_nsn(va, (KA_T)v->v_data, &s))
 		return;
@@ -1147,6 +1162,9 @@ vfs_read_error:
 		if (read_npn(va, (KA_T)v->v_data, &pc))
 		    return;
 		break;
+	    case N_SAMFS:
+		(void) add_nma(SAMFS_NMA_MSG, (int)strlen(SAMFS_NMA_MSG));
+		break;
 	    case N_STREAM:
 		if (vs) {
 		    Lf->is_stream = 1;
@@ -1263,7 +1281,7 @@ vfs_read_error:
 		    (void) snpf(Namech, Namechl, "%s", sdp->name);
 		} else
 		    devs = 0;
-		nl = snl = strlen(Namech);
+		nl = snl = (int)strlen(Namech);
 		if ((len = read_nusa(&so.so_laddr, &ua))) {
 		    if (Sfile
 		    &&  is_file_named(ua.sun_path, Ntype, VSOCK, 0))
@@ -1320,7 +1338,7 @@ vfs_read_error:
 			    print_kptr(peer, (char *)NULL, 0));
 		    else
 			(void) snpf(ubuf, sizeof(ubuf), "(socketpair)");
-		    len = strlen(ubuf);
+		    len = (int)strlen(ubuf);
 		    sepl = Namech[0] ? 2 : 0;
 		    if (len > (Namechl - nl - sepl - 1))
 			len = Namechl - nl - sepl - 1;
@@ -1346,7 +1364,7 @@ vfs_read_error:
 		    print_kptr((KA_T)v->v_data, (char *)NULL, 0),
 		    soa ? "->" : "",
 		    soa ? print_kptr(soa, tbuf, sizeof(tbuf)) : "");
-		len = strlen(ubuf);
+		len = (int)strlen(ubuf);
 		if (len <= (Namechl - nl - 1)) {
 		    (void) snpf(&Namech[nl], Namechl - nl, "%s", ubuf);
 		    nl += len;
@@ -1358,7 +1376,7 @@ vfs_read_error:
 		    (void) snpf(ubuf, sizeof(ubuf), "%s(Vnode=%s)",
 			Namech[0] ? " " : "",
 			print_kptr((KA_T)so.so_ux_bound_vp, (char *)NULL, 0));
-		    len = strlen(ubuf);
+		    len = (int)strlen(ubuf);
 		    if (len <= (Namechl - nl - 1)) {
 			(void) snpf(&Namech[nl], Namechl - nl, "%s", ubuf);
 			nl += len;
@@ -1409,6 +1427,15 @@ vfs_read_error:
 	    break;
 #endif	/* defined(HASPROCFS) */
 
+	case N_SAMFS:
+	    if ((v->v_type == VCHR) || (v->v_type == VBLK)) {
+		rdev = v->v_rdev;
+		rdevs = 1;
+	    } else if (vfs) {
+		dev = vfs->dev;
+		devs = 1;
+	    }
+	    break;
 	case N_SPEC:
 	    if (((Ntype = vty) == N_STREAM) && so_st) {
 		if (Funix)
@@ -1435,8 +1462,11 @@ vfs_read_error:
 			    (void) snpf(ubuf, sizeof(ubuf), "(->%s)",
 				print_kptr(so_ad[1], (char *)NULL, 0));
 		    }
-		    if (!Lf->nma && (Lf->nma = (char *) malloc(strlen(ubuf)+1)))
-			(void) snpf(Lf->nma, strlen(ubuf) + 1, "%s", ubuf);
+		    if (!Lf->nma && (Lf->nma = (char *)
+					       malloc((int)strlen(ubuf) + 1)))
+		    {
+			(void) snpf(Lf->nma, (int)strlen(ubuf) + 1, "%s", ubuf);
+		    }
 		} else if (soso.lux_dev.addr.tu_addr.ino) {
 		    if (vfs) {
 			dev = vfs->dev;
@@ -1467,8 +1497,8 @@ vfs_read_error:
 			    if (Sfile
 			    &&  is_file_named(ua.sun_path, Ntype, type, 0))
 				Lf->sf |= SELNM;
-			    len = strlen(ua.sun_path);
-			    nl = strlen(Namech);
+			    len = (int)strlen(ua.sun_path);
+			    nl = (int)strlen(Namech);
 			    sepl = Namech[0] ? 2 : 0;
 			    if (len > (Namechl - nl - sepl - 1))
 				len = Namechl - nl - sepl - 1;
@@ -1664,14 +1694,16 @@ vfs_read_error:
 		    Lf->inp_ty = 1;
 	    }
 	    break;
+	case N_SAMFS:
+	    break;		/* No more SAM-FS information is available. */
 	case N_STREAM:
 	    if (so_st && soso.lux_dev.addr.tu_addr.ino) {
 		if (Lf->inp_ty) {
-		    nl = Lf->nma ? strlen(Lf->nma) : 0;
+		    nl = Lf->nma ? (int)strlen(Lf->nma) : 0;
 		    (void) snpf(ubuf, sizeof(ubuf),
 			"%s(Inode=%lu)", nl ? " " : "",
 			(unsigned long)soso.lux_dev.addr.tu_addr.ino);
-		    len = nl + strlen(ubuf) + 1;
+		    len = nl + (int)strlen(ubuf) + 1;
 		    if (Lf->nma)
 			Lf->nma = (char *) realloc(Lf->nma, len);
 		    else
@@ -1807,6 +1839,8 @@ vfs_read_error:
 		} else if ((type == VCHR || type == VBLK) && !Fsize)
 		    Lf->off_def = 1;
 		break;
+	    case N_SAMFS:
+		break;		/* No more SAM-FS information is available. */
 	    case N_STREAM:
 		if (!Fsize)
 		    Lf->off_def = 1;
@@ -1904,6 +1938,8 @@ vfs_read_error:
 		    Lf->nlink_def = 1;
 		}
 		break;
+	    case N_SAMFS:
+		break;		/* No more SAM-FS information is available. */
 	    case N_STREAM:
 		break;
 	    case N_TMP:
@@ -2247,7 +2283,7 @@ vfs_read_error:
 		    if (!Namech[0] || Lf->is_com)
 			(void) snpf(Namech, Namechl, "%s", sdp->name);
 		    if (Lf->is_com && !Lf->nma) {
-			len = strlen("(COMMON)") + 1;
+			len = (int)strlen("(COMMON)") + 1;
 			if (!(Lf->nma = (char *) malloc(len))) {
 			    (void) fprintf(stderr,
 				"%s: no space for (COMMON): PID %d; FD %s\n",
@@ -2449,7 +2485,7 @@ read_mi(s, rdev, so, so_st, so_ad, sdp)
 	    dp = finddev(&DevDev, rdev, LOOKDEV_ALL);
 	if (dp) {
 	    (void) snpf(Namech, Namechl, "%s", dp->name);
-	    k = strlen(Namech);
+	    k = (int)strlen(Namech);
 	    *sdp = dp;
 	} else
 	    (void) snpf(Lf->iproto, sizeof(Lf->iproto), "STR");
@@ -2468,7 +2504,7 @@ read_mi(s, rdev, so, so_st, so_ad, sdp)
 	    if ((ka = (KA_T)mi.mi_idname) == (KA_T)NULL
 	    ||  kread(ka, mn, nl))
 		continue;
-	    if ((j = strlen(mn)) < 1)
+	    if ((j = (int)strlen(mn)) < 1)
 		continue;
 	    if (j >= 4 && strcmp(&mn[j - 4], "head") == 0)
 		continue;
@@ -3193,7 +3229,7 @@ read_nusa(so, ua)
 	if (len >= sizeof(ua->sun_path))
 	    len = sizeof(ua->sun_path) - 1;
 	ua->sun_path[len] = '\0';
-	return(strlen(ua->sun_path));
+	return((int)strlen(ua->sun_path));
 }
 #endif	/* solaris>=20600 */
 
@@ -3400,7 +3436,8 @@ vop2ty(vp)
 	if (!vp->v_op)
 		return(-1);
 	if ((Uvops && Uvops == (KA_T)vp->v_op)
-	||  (Spvops && Spvops == (KA_T)vp->v_op))
+	||  (Spvops && Spvops == (KA_T)vp->v_op)
+	)
 	    return(N_REGLR);
 	if (Nvops && Nvops == (KA_T)vp->v_op)
 	    return(N_NFS);
@@ -3443,6 +3480,8 @@ vop2ty(vp)
 	    return(N_NM);
 	else if (Prvops && Prvops == (KA_T)vp->v_op)
 	    return(N_PROC);
+	else if (Samvops && Samvops == (KA_T)vp->v_op)
+	    return(N_SAMFS);
 	else if (Sckvops && Sckvops == (KA_T)vp->v_op)
 	    return(N_SOCK);
 
