@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: lsof.h,v 1.46 2002/06/17 01:38:15 abe Exp $
+ * $Id: lsof.h,v 1.49 2003/06/11 11:36:27 abe Exp $
  */
 
 
@@ -232,7 +232,7 @@ static struct utmp dummy_utmp;		/* to get login name length */
 #define	LOGINML		sizeof(dummy_utmp.ut_name)
 					/* login name length */
 #define	LPROCINCR	128		/* Lproc[] allocation increment */
-#define	LSOF_URL	"ftp://vic.cc.purdue.edu/pub/tools/unix/lsof/"
+#define	LSOF_URL	"ftp://lsof.itap.purdue.edu/pub/tools/unix/lsof/"
 #define	MIN_AF_ADDR	sizeof(struct in_addr)
 					/* minimum AF_* address length */
 
@@ -277,13 +277,14 @@ static struct utmp dummy_utmp;		/* to get login name length */
 #define	N_PIPE		24		/* pipe device node */
 #define	N_PROC		25		/* /proc node */
 #define	N_PSEU		26		/* pseudofs node */
-#define	N_SOCK		27		/* sock_vnodeops node */
-#define	N_SPEC		28		/* spec_vnodeops node */
-#define	N_STREAM	29		/* stream node */
-#define	N_TMP		30		/* tmpfs node */
-#define	N_UFS		31		/* Unix file system node */
-#define	N_VXFS		32		/* Veritas file system node */
-#define	N_XFS		33		/* XFS node */
+#define	N_SAMFS		27		/* Solaris SAM-FS */
+#define	N_SOCK		28		/* sock_vnodeops node */
+#define	N_SPEC		29		/* spec_vnodeops node */
+#define	N_STREAM	30		/* stream node */
+#define	N_TMP		31		/* tmpfs node */
+#define	N_UFS		32		/* Unix file system node */
+#define	N_VXFS		33		/* Veritas file system node */
+#define	N_XFS		34		/* XFS node */
 
 # if	!defined(OFFDECDIG)
 #define	OFFDECDIG	8		/* maximum number of digits in the
@@ -473,6 +474,7 @@ struct str_lst {
 	struct str_lst *next;		/* next list entry */
 };
 extern struct str_lst *Cmdl;
+extern int CmdLim;
 
 # if	defined(HASDCACHE)
 extern unsigned DCcksum;
