@@ -360,7 +360,7 @@ print_errno:
 /*
  * Set a SIGALRM, then accept() the connection from the client.
  *
- * Save the client'ss socket address.
+ * Save the client's socket address.
  *
  * Replace the server's FD with the accepted one and close the original.
  */
@@ -836,7 +836,7 @@ client_errno:
 /*
  * Set an alarm timeout and connect to the server.
  */
-    (void) signal(SIGALRM, HandleSrvrAlarm);
+    (void) signal(SIGALRM, HandleClntAlarm);
     (void) alarm(ALARMTM);
     cr = connect(fd, (struct sockaddr *)cad, sizeof(struct sockaddr_in));
     (void) alarm(0);
