@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1998 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: usage.c,v 1.19 2002/12/13 14:44:08 abe Exp $";
+static char *rcsid = "$Id: usage.c,v 1.20 2003/03/21 17:25:10 abe Exp $";
 #endif
 
 
@@ -346,7 +346,7 @@ usage(xv, fh, version)
 	    (void) fprintf(stderr, " [-A A]");
 #endif	/* defined(HAS_AFS) && defined(HASAOPT) */
 
-	    (void) fprintf(stderr, " [-c c] [+|-d s] [+%sD D]",
+	    (void) fprintf(stderr, " [+|-c c] [+|-d s] [+%sD D]",
 
 #if	defined(HASDCACHE)
 		"|-"
@@ -395,7 +395,10 @@ usage(xv, fh, version)
 	    (void) fprintf(stderr, "  %-25.25s", "-a AND selections (OR)");
 	    (void) fprintf(stderr, "  %s\n", "-b avoid kernel blocks");
 	    (void) fprintf(stderr, "  %-23.23s", "-c c  cmd c, /c/[bix]");
-	    (void) fprintf(stderr, "  %-25.23s",
+	    (void) snpf(buf, sizeof(buf), "+c w  COMMAND width (%d)", CMDL);
+	    (void) fprintf(stderr, "  %-25.25s", buf);
+
+	    (void) fprintf(stderr, "  %s\n", 
 
 #if	defined(HASNCACHE)
 		"-C no kernel name cache");
@@ -403,9 +406,9 @@ usage(xv, fh, version)
 		" ");
 #endif	/* defined(HASNCACHE) */
 
-	    (void) fprintf(stderr, "  %s\n", "+d s  dir s files");
-	    (void) fprintf(stderr, "  %-23.23s", "-d s  select by FD set");
-	    (void) fprintf(stderr, "  %-25.25s", "+D D  dir D tree *SLOW?*");
+	    (void) fprintf(stderr, "  %-23.23s", "+d s  dir s files");
+	    (void) fprintf(stderr, "  %-25.25s", "-d s  select by FD set");
+	    (void) fprintf(stderr, "  %s\n", "+D D  dir D tree *SLOW?*");
 
 #if	defined(HASDCACHE)
 	    if (Setuidroot)
@@ -423,7 +426,7 @@ usage(xv, fh, version)
 	    (void) snpf(buf, sizeof(buf), " ");
 #endif	/* defined(HASDCACHE) */
 
-	    (void) fprintf(stderr, "  %s\n", buf);
+	    (void) fprintf(stderr, "  %-23.23s", buf);
 	    (void) snpf(buf, sizeof(buf), "-i select IPv%s files",
 
 #if	defined(HASIPv6)
@@ -433,14 +436,14 @@ usage(xv, fh, version)
 #endif	/* defined(HASIPv6) */
 
 			  );
-	    (void) fprintf(stderr, "  %-23.23s", buf);
-	    (void) fprintf(stderr, "  %-25.25s", "-l list UID numbers");
-	    (void) fprintf(stderr, "  %s\n", "-n no host names");
-	    (void) fprintf(stderr, "  %-23.23s", "-N select NFS files");
-	    (void) fprintf(stderr, "  %-25.25s", "-o list file offset");
-	    (void) fprintf(stderr, "  %s\n", "-O avoid overhead *RISKY*");
-	    (void) fprintf(stderr, "  %-23.23s", "-P no port names");
-	    (void) fprintf(stderr, "  %-25.25s",
+	    (void) fprintf(stderr, "  %-25.25s", buf);
+	    (void) fprintf(stderr, "  %s\n", "-l list UID numbers");
+	    (void) fprintf(stderr, "  %-23.23s", "-n no host names");
+	    (void) fprintf(stderr, "  %-25.25s", "-N select NFS files");
+	    (void) fprintf(stderr, "  %s\n", "-o list file offset");
+	    (void) fprintf(stderr, "  %-23.23s", "-O avoid overhead *RISKY*");
+	    (void) fprintf(stderr, "  %-25.25s", "-P no port names");
+	    (void) fprintf(stderr, "  %s\n",
 
 #if	defined(HASPPID)
 	 	"-R list paRent PID"
@@ -449,12 +452,12 @@ usage(xv, fh, version)
 #endif	/* defined(HASPPID) */
 
 	    );
-	    (void) fprintf(stderr, "  %s\n", "-s list file size");
-	    (void) fprintf(stderr, "  %-23.23s", "-t terse listing");
-	    (void) fprintf(stderr, "  %-25.25s", "-T disable TCP/TPI info");
-	    (void) fprintf(stderr, "  %s\n", "-U select Unix socket");
-	    (void) fprintf(stderr, "  %-23.23s", "-v list version info");
-	    (void) fprintf(stderr, "  %-25.25s", "-V verbose search");
+	    (void) fprintf(stderr, "  %-23.23s", "-s list file size");
+	    (void) fprintf(stderr, "  %-25.25s", "-t terse listing");
+	    (void) fprintf(stderr, "  %s\n", "-T disable TCP/TPI info");
+	    (void) fprintf(stderr, "  %-23.23s", "-U select Unix socket");
+	    (void) fprintf(stderr, "  %-25.25s", "-v list version info");
+	    (void) fprintf(stderr, "  %s\n", "-V verbose search");
 	    (void) snpf(buf, sizeof(buf), "+|-w  Warnings (%s)",
 
 #if	defined(WARNINGSTATE)
@@ -464,18 +467,21 @@ usage(xv, fh, version)
 #endif	/* defined(WARNINGSTATE) */
 
 	    );
-	    (void) fprintf(stderr, "  %s\n", buf);
+	    (void) fprintf(stderr, "  %-23.23s", buf);
 
 #if	defined(HASXOPT)
 # if	defined(HASXOPT_ROOT)
 	    if (Myuid == 0)
 		(void) snpf(buf, sizeof(buf), "-X %s", HASXOPT);
+	    buf[0] = '\0';
 # else	/* !defined(HASXOPT_ROOT) */
 	    (void) snpf(buf, sizeof(buf), "-X %s", HASXOPT);
 # endif	/* defined(HASXOPT_ROOT) */
-	    (void) fprintf(stderr, "  %-23.23s", buf);
+# else	/* !defined(HASXOPT) */
+	    buf[0] = '\0';
 #endif	/* defined(HASXOPT) */
 
+	    (void) fprintf(stderr, "  %-25.25s", buf);
 	    (void) fprintf(stderr, "  %s\n", "-- end option scan");
 	    (void) fprintf(stderr, "  %-36.36s",
 		"+f|-f  +filesystem or -file names");
